@@ -79,6 +79,8 @@
 #define XFS_SUPER_MAGIC 0x58465342
 #endif
 
+#define xfs_isset(a,i)	((a)[(i)/(sizeof((a))*NBBY)] & (1<<((i)%(sizeof((a))*NBBY))))
+
 /*
  * Argument structure for libxfs_init().
  */
@@ -143,6 +145,7 @@ extern int	libxfs_log_header (xfs_caddr_t, uuid_t *, int, int, int,
 struct xfs_inode;
 typedef struct xfs_mount {
 	xfs_sb_t		m_sb;		/* copy of fs superblock */
+	char			*m_fsname;	/* filesystem name */
 	int			m_bsize;	/* fs logical block size */
 	xfs_agnumber_t		m_agfrotor;	/* last ag where space found */
 	xfs_agnumber_t		m_agirotor;	/* last ag dir inode alloced */
@@ -204,7 +207,7 @@ typedef struct xfs_mount {
 extern xfs_mount_t	*libxfs_mount (xfs_mount_t *, xfs_sb_t *,
 				dev_t, dev_t, dev_t, int);
 extern void	libxfs_mount_common (xfs_mount_t *, xfs_sb_t *);
-extern void	libxfs_initialize_perag (xfs_mount_t *, int);
+extern xfs_agnumber_t	libxfs_initialize_perag (xfs_mount_t *, xfs_agnumber_t);
 extern void	libxfs_umount (xfs_mount_t *);
 extern int	libxfs_rtmount_init (xfs_mount_t *);
 extern void	libxfs_alloc_compute_maxlevels (xfs_mount_t *);
