@@ -52,6 +52,29 @@ usage(void)
 	exit(1);
 }
 
+void
+init_commands(void)
+{
+	attr_init();
+	bmap_init();
+	fadvise_init();
+	file_init();
+	freeze_init();
+	fsync_init();
+	help_init();
+	inject_init();
+	mmap_init();
+	open_init();
+	pread_init();
+	prealloc_init();
+	pwrite_init();
+	quit_init();
+	resblks_init();
+	sendfile_init();
+	shutdown_init();
+	truncate_init();
+}
+
 void
 init(
 	int		argc,
@@ -142,17 +165,20 @@ main(
 	int	argc,
 	char	**argv)
 {
-	int	c, i, done = 0;
+	int	c, i, j, done = 0;
 	char	*input;
 	char	**v;
 
 	init(argc, argv);
 
 	for (i = 0; !done && i < ncmdline; i++) {
-		v = breakline(cmdline[i], &c);
-		if (c)
-			done = command(c, v);
-		free(v);
+		for (j = 0; !done && j < filecount; j++) {
+			file = &filetable[j];
+			v = breakline(cmdline[i], &c);
+			if (c)
+				done = command(c, v);
+			free(v);
+		}
 	}
 	if (cmdline) {
 		free(cmdline);
