@@ -57,6 +57,7 @@ pread_help(void)
 }
 
 void	*buffer;
+ssize_t	highwater;
 ssize_t	buffersize;
 
 int
@@ -65,16 +66,18 @@ alloc_buffer(
 	int		uflag,
 	unsigned int	seed)
 {
-	if (bsize > buffersize) {
+	if (bsize > highwater) {
 		if (buffer)
 			free(buffer);
-		buffer = memalign(getpagesize(), buffersize = bsize);
+		buffer = memalign(pagesize, bsize);
 		if (!buffer) {
 			perror("memalign");
-			buffersize = 0;
+			highwater = buffersize = 0;
 			return -1;
 		}
+		highwater = bsize;
 	}
+	buffersize = bsize;
 	if (!uflag)
 		memset(buffer, seed, buffersize);
 	return 0;
@@ -146,7 +149,7 @@ pread_f(
 {
 	off64_t		offset;
 	long long	count, total;
-	unsigned int	blocksize, sectsize;
+	int		blocksize, sectsize;
 	struct timeval	t1, t2;
 	char		s1[64], s2[64], ts[64];
 	int		uflag = 0, vflag = 0;
